Learn R Programming

EpiDynamics (version 0.3.1)

EpiDynamics-package: The EpiDynamics Package

Description

Mathematical models of infectious diseases in humans and animals. Both, deterministic and stochastic models can be simulated and plotted.

Arguments

Details

Package: EpiDynamics
Type: Package
Version: 0.3.1
Date: 2020-02-11
Depends: R (>= 3.6)
Imports: deSolve, reshape2, ggplot2, grid
License: GPL (>= 2)
LazyLoad: yes
URL: http://oswaldosantos.github.io/EpiDynamics
Authors: Oswaldo Santos Baquero [email protected]
Fernando Silveira Marques [email protected]
Maintainer: Oswaldo Santos Baquero [email protected]